@@ -25,13 +25,14 @@
 # program. If not, see <http://www.apache.org/licenses/LICENSE-2.0>.
 
 
-import sys
 import os
 import json
 import pandas as pd
 
 from ._version import __version__
 
+HERE = os.path.dirname(__file__)
+
 
 def _json_table_to_df(json_table):
     table = json.loads(json_table)
@@ -55,7 +56,7 @@ class _VariableHandler(object):
     def __init__(self, variable_evaluate_map, handlername):
         self.variable_evaluate_map = json.loads(variable_evaluate_map)
         self.handlername = handlername
-        
+
         self.timestamp = dict()
         for key in self.variable_evaluate_map:
             self.timestamp[key] = None
@@ -71,7 +72,6 @@ class _VariableHandler(object):
         self.value = dict()
         self.defined = dict()
 
-
     @property
     def fetch_code(self):
         fetch_code_list = ["{}.value = dict()\n".format(self.handlername)]
@@ -83,11 +83,11 @@ try:
 except:
     {0}.defined["{1}"] = False
 """.format(self.handlername, key, evaluate))
-        fetch_code_list.append("print({}.variables_json)".format(self.handlername))
+        fetch_code_list.append(
+            "print({}.variables_json)".format(self.handlername))
 
         return ''.join(fetch_code_list)
 
-
     @property
     def variables_dict(self):
         variables = dict()
@@ -107,9 +107,25 @@ except:
                 }
         return variables
 
-
     @property
     def variables_json(self):
         json_string = json.dumps(self.variables_dict, indent=2, sort_keys=True)
-        json_string = json_string.replace('NaN', 'null').replace('-Infinity', 'null').replace('Infinity', 'null')
+        json_string = (
+            json_string.replace('NaN', 'null')
+            .replace('-Infinity', 'null').replace('Infinity', 'null'))
         return json_string
+
+
+def _print_file(filename):
+    with open(filename, 'r') as f:
+        contents = f.read()
+
+    print(contents)
+
+
+def _print_apache():
+    _print_file(os.path.join(HERE, 'Apache-2.0'))
+
+
+def _print_agpl():
+    _print_file(os.path.join(HERE, 'LICENSE'))
