@@ -28,21 +28,28 @@
 import sys
 import os
 import argparse
-from glob import glob
 
 from notebook.notebookapp import NotebookApp
-from notebook.base.handlers import IPythonHandler, FileFindHandler
 
-HERE = os.path.dirname(__file__)
+from ._api_handlers import get_api_handlers
+from ._scriptedforms_handlers import get_scriptedforms_handlers
 
 
+def _jupyter_server_extension_paths():
+    return [{
+        "module": "scriptedforms"
+    }]
 
-class _ScriptedFormsHandler(IPythonHandler):
-    def get(self):
-        with open(os.path.join(HERE, 'index.html'), 'r') as f:
-            template = f.read()
 
-        return self.write(template)
+def load_jupyter_server_extension(notebook_app):
+    api_handlers = get_api_handlers(
+        notebook_app.port, notebook_app.notebook_dir)
+    scriptedforms_handlers = get_scriptedforms_handlers()
+
+    handlers = api_handlers + scriptedforms_handlers
+
+    web_app = notebook_app.web_app
+    web_app.add_handlers('.*$', handlers)
 
 
 class ScriptedForms(NotebookApp):
@@ -56,19 +63,17 @@ class ScriptedForms(NotebookApp):
     """
 
     def start(self):
-        handlers = [
-            (r'/scriptedforms/.*\.md', _ScriptedFormsHandler),
-            (
-                r"/scriptedforms/(.*)", FileFindHandler,
-                {'path': os.path.join(HERE, 'lib')}
-            )
-        ]
+        api_handlers = get_api_handlers(
+            self.port, self.notebook_dir)
+        scriptedforms_handlers = get_scriptedforms_handlers()
+
+        handlers = api_handlers + scriptedforms_handlers
+
         self.web_app.add_handlers(".*$", handlers)
         super(ScriptedForms, self).start()
 
 
 def load(filepath):
-
     absolute_path = os.path.abspath(filepath)
     if not os.path.exists(absolute_path):
         raise ValueError('file does not exist')
@@ -86,8 +91,8 @@ def main():
     parser = argparse.ArgumentParser(description='ScriptedForms.')
     parser.add_argument(
         'filepath', help='The file path of the form to open.')
-       
-    args = parser.parse_args()    
+
+    args = parser.parse_args()
     load(args.filepath)
 
 
